import { useState } from 'react';
import { Link } from 'react-router-dom';
import { FaThumbsUp, FaComment, FaShare } from 'react-icons/fa';
import RatingChart from './RatingChart';

function ReviewCard({ review, isDetailed = false }) {
  const [isExpanded, setIsExpanded] = useState(false);
  
  const {
    id,
    user,
    content,
    ratings,
    likes,
    comments,
    createdAt,
    spoiler
  } = review;
  
  // Format date
  const formattedDate = new Date(createdAt).toLocaleDateString('en-US', {
    year: 'numeric',
    month: 'short',
    day: 'numeric'
  });
  
  // Calculate overall rating
  const overallRating = Object.values(ratings).reduce((sum, rating) => sum + rating, 0) / Object.keys(ratings).length;
  
  // Handle content length
  const isLongContent = content.length > 300;
  const displayContent = isLongContent && !isExpanded ? `${content.substring(0, 280)}...` : content;
  
  return (
    <div className={`bg-campfire-charcoal rounded-lg shadow-lg p-6 mb-6 ${isDetailed ? 'border border-campfire-ash' : ''}`}>
      {/* Review Header */}
      <div className="flex justify-between items-start mb-4">
        <div className="flex items-center">
          <Link to={`/profile/${user.id}`}>
            <img
              src={user.profilePicture || 'https://via.placeholder.com/40'}
              alt={user.username}
              className="w-10 h-10 rounded-full object-cover mr-3"
            />
          </Link>
          <div>
            <Link to={`/profile/${user.id}`} className="font-medium text-campfire-light hover:text-campfire-amber">
              {user.username}
            </Link>
            {user.isCritic && (
              <span className="ml-2 inline-block px-2 py-0.5 text-xs font-medium bg-campfire-amber text-campfire-dark rounded-full">
                Critic
              </span>
            )}
            <div className="text-sm text-campfire-ash">{formattedDate}</div>
          </div>
        </div>
        <div className="flex items-center">
          <span className="inline-flex items-center justify-center w-10 h-10 rounded-full bg-campfire-amber text-campfire-dark font-bold">
            {overallRating.toFixed(1)}
          </span>
        </div>
      </div>
      
      {/* Review Content */}
      <div className={`${isDetailed ? 'grid grid-cols-1 md:grid-cols-3 gap-8' : ''}`}>
        <div className={`${isDetailed ? 'md:col-span-2' : ''}`}>
          {/* Spoiler Warning */}
          {spoiler && (
            <div className="bg-status-warning bg-opacity-20 text-status-warning p-3 rounded-md mb-4">
              <span className="font-bold">Spoiler Warning:</span> This review contains spoilers.
            </div>
          )}
          
          {/* Review Text */}
          <p className="text-campfire-light mb-4">
            {displayContent}
          </p>
          
          {/* Expand/Collapse for long content */}
          {isLongContent && (
            <button
              onClick={() => setIsExpanded(!isExpanded)}
              className="text-campfire-amber hover:text-campfire-ember mb-4 text-sm font-medium"
            >
              {isExpanded ? 'Show Less' : 'Read More'}
            </button>
          )}
        </div>
        
        {/* Rating Chart */}
        <div className={`${isDetailed ? 'md:col-span-1' : 'hidden md:block'}`}>
          <RatingChart 
            ratings={ratings} 
            size={isDetailed ? 'medium' : 'small'} 
            showLegend={isDetailed}
          />
        </div>
      </div>
      
      {/* Review Footer */}
      <div className="flex items-center justify-between mt-6 pt-4 border-t border-campfire-dark">
        <div className="flex space-x-6">
          <button className="flex items-center text-campfire-ash hover:text-campfire-amber">
            <FaThumbsUp className="mr-2" />
            <span>{likes}</span>
          </button>
          <button className="flex items-center text-campfire-ash hover:text-campfire-amber">
            <FaComment className="mr-2" />
            <span>{comments.length}</span>
          </button>
        </div>
        <button className="flex items-center text-campfire-ash hover:text-campfire-amber">
          <FaShare className="mr-2" />
          <span>Share</span>
        </button>
      </div>
    </div>
  );
}

export default ReviewCard;