import React, { createContext, useContext, useState } from 'react';
import { searchMedia, getMediaDetails, validateMediaData, formatMediaData } from '../services/mediaService';
import { createMedia } from '../services/supabase';

const MediaContext = createContext();

export const useMedia = () => {
  const context = useContext(MediaContext);
  if (!context) {
    throw new Error('useMedia must be used within a MediaProvider');
  }
  return context;
};

export const MediaProvider = ({ children }) => {
  const [searchResults, setSearchResults] = useState([]);
  const [selectedMedia, setSelectedMedia] = useState(null);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);

  const handleSearch = async (query, type = 'movie') => {
    try {
      setLoading(true);
      setError(null);
      const results = await searchMedia(query, type);
      setSearchResults(results);
    } catch (error) {
      console.error('Search error:', error);
      setError('Ошибка при поиске медиа');
    } finally {
      setLoading(false);
    }
  };

  const handleSelectMedia = async (tmdbId, type) => {
    try {
      setLoading(true);
      setError(null);
      const details = await getMediaDetails(tmdbId, type);
      setSelectedMedia(details);
    } catch (error) {
      console.error('Error fetching media details:', error);
      setError('Ошибка при получении деталей медиа');
    } finally {
      setLoading(false);
    }
  };

  const handleCreateMedia = async (mediaData) => {
    try {
      setLoading(true);
      setError(null);

      // Валидация данных
      const errors = validateMediaData(mediaData);
      if (errors.length > 0) {
        throw new Error(errors.join('\n'));
      }

      // Форматирование данных
      const formattedData = formatMediaData(mediaData);

      // Создание медиа
      const newMedia = await createMedia(formattedData);
      return newMedia;
    } catch (error) {
      console.error('Error creating media:', error);
      setError(error.message || 'Ошибка при создании медиа');
      throw error;
    } finally {
      setLoading(false);
    }
  };

  const value = {
    searchResults,
    selectedMedia,
    loading,
    error,
    handleSearch,
    handleSelectMedia,
    handleCreateMedia
  };

  return (
    <MediaContext.Provider value={value}>
      {children}
    </MediaContext.Provider>
  );
};
