import { useState } from "react";
import { Link, useNavigate } from "react-router-dom";
import { useAuth } from "../contexts/AuthContext";

function RegisterPage() {
  const [email, setEmail] = useState("");
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [confirmPassword, setConfirmPassword] = useState("");
  const [error, setError] = useState("");
  const [loading, setLoading] = useState(false);

  const { signup } = useAuth();
  const navigate = useNavigate();

  const handleSubmit = async (e) => {
    e.preventDefault();

    if (!email || !username || !password || !confirmPassword) {
      setError("Заполни все поля");
      return;
    }

    if (password !== confirmPassword) {
      setError("Хмм, пароли не совпадают...");
      return;
    }

    if (password.length < 6) {
      setError("Коротковато...");
      return;
    }

    try {
      setError("");
      setLoading(true);
      await signup(email, password, username);
      navigate("/");
    } catch (err) {
      setError(
        "Дружище, ты уже существуешь, либо кто-то другой зарегистрирован с такой же почтой."
      );
      console.error(err);
    } finally {
      setLoading(false);
    }
  };

  return (
    <div className="pt-20 min-h-screen flex items-center justify-center">
      <div className="container-custom max-w-md py-12">
        <div className="bg-campfire-charcoal rounded-lg shadow-lg p-8">
          <h1 className="text-3xl font-bold mb-6 text-center">
            Присоединиться к CampFire Critics
          </h1>
          <p className="text-campfire-ash mb-8 text-center">
            Создай свою учетную запись CampFire, чтобы оценивать и рецензировать
            все что движется.
          </p>

          {error && (
            <div className="bg-status-error bg-opacity-20 text-status-error p-4 rounded-md mb-6">
              {error}
            </div>
          )}

          <form onSubmit={handleSubmit}>
            <div className="mb-6">
              <label htmlFor="email" className="block text-campfire-light mb-2">
                Email
              </label>
              <input
                type="email"
                id="email"
                value={email}
                onChange={(e) => setEmail(e.target.value)}
                className="input w-full"
                placeholder="your@campfiregg.ru"
                required
              />
            </div>

            <div className="mb-6">
              <label
                htmlFor="username"
                className="block text-campfire-light mb-2"
              >
                Имя пользователя
              </label>
              <input
                type="text"
                id="username"
                value={username}
                onChange={(e) => setUsername(e.target.value)}
                className="input w-full"
                placeholder="Say. Your. Name"
                required
              />
            </div>

            <div className="mb-6">
              <label
                htmlFor="password"
                className="block text-campfire-light mb-2"
              >
                Пароль
              </label>
              <input
                type="password"
                id="password"
                value={password}
                onChange={(e) => setPassword(e.target.value)}
                className="input w-full"
                placeholder="••••••••"
                required
              />
              <p className="text-xs text-campfire-ash mt-1">
                Не меньше 6 знаков
              </p>
            </div>

            <div className="mb-8">
              <label
                htmlFor="confirm-password"
                className="block text-campfire-light mb-2"
              >
                Пароль пароль
              </label>
              <input
                type="password"
                id="confirm-password"
                value={confirmPassword}
                onChange={(e) => setConfirmPassword(e.target.value)}
                className="input w-full"
                placeholder="••••••••"
                required
              />
            </div>

            <button
              type="submit"
              disabled={loading}
              className="btn-primary w-full"
            >
              {loading ? "Запечатываем..." : "Создать"}
            </button>
          </form>

          <div className="mt-6 text-center">
            <span className="text-campfire-ash">Уже в строю?</span>{" "}
            <Link
              to="/login"
              className="text-campfire-amber hover:text-campfire-ember"
            >
              Войти
            </Link>
          </div>
        </div>
      </div>
    </div>
  );
}

export default RegisterPage;
